/****************************************************************************
** Meta object code from reading C++ file 'QrCodeContent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qrca-26.04.3/src/QrCodeContent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'QrCodeContent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QrCodeContentE_t {};
} // unnamed namespace

template <> constexpr inline auto QrCodeContent::qt_create_metaobjectdata<qt_meta_tag_ZN13QrCodeContentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QrCodeContent",
        "contentType",
        "ContentType",
        "text",
        "isPlainText",
        "Url",
        "VCard",
        "OtpToken",
        "TransportTicket",
        "HealthCertificate",
        "Text",
        "Binary",
        "ISBN",
        "EAN",
        "WifiSetting"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'contentType'
        QtMocHelpers::PropertyData<enum ContentType>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'isPlainText'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ContentType'
        QtMocHelpers::EnumData<enum ContentType>(2, 2, QMC::EnumFlags{}).add({
            {    5, ContentType::Url },
            {    6, ContentType::VCard },
            {    7, ContentType::OtpToken },
            {    8, ContentType::TransportTicket },
            {    9, ContentType::HealthCertificate },
            {   10, ContentType::Text },
            {   11, ContentType::Binary },
            {   12, ContentType::ISBN },
            {   13, ContentType::EAN },
            {   14, ContentType::WifiSetting },
        }),
    };
    return QtMocHelpers::metaObjectData<QrCodeContent, qt_meta_tag_ZN13QrCodeContentE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QrCodeContent::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QrCodeContentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QrCodeContentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QrCodeContentE_t>.metaTypes,
    nullptr
} };

void QrCodeContent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QrCodeContent *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ContentType*>(_v) = _t->contentType(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isPlainText(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
