/****************************************************************************
** Meta object code from reading C++ file 'Qrca.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qrca-26.04.3/src/Qrca.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Qrca.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4QrcaE_t {};
} // unnamed namespace

template <> constexpr inline auto Qrca::qt_create_metaobjectdata<qt_meta_tag_ZN4QrcaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Qrca",
        "wifiModeChanged",
        "",
        "connectingToWifiChanged",
        "connectingToWifi",
        "passiveNotificationRequested",
        "text",
        "encodeTextChanged",
        "wifiConnected",
        "wifiConnectionFailed",
        "errorMsg",
        "newQrCodeSaveLocation",
        "saveVCard",
        "getVCardName",
        "copyToClipboard",
        "QrCodeContent",
        "content",
        "copyImageToClipboard",
        "QImage",
        "image",
        "hasApplication",
        "appId",
        "applicationIconName",
        "openInApplication",
        "wifiName",
        "wifiSetting",
        "canConnectToWifi",
        "connectToWifi",
        "wifiCode",
        "resultContent",
        "Prison::ScanResult",
        "result",
        "scanImage",
        "QUrl",
        "imagePath",
        "encodeText",
        "wifiMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wifiModeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectingToWifiChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'passiveNotificationRequested'
        QtMocHelpers::SignalData<void(QString)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'encodeTextChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wifiConnected'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wifiConnectionFailed'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'newQrCodeSaveLocation'
        QtMocHelpers::MethodData<QString()>(11, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'saveVCard'
        QtMocHelpers::MethodData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'getVCardName'
        QtMocHelpers::MethodData<QString(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 },
        }}),
        // Method 'copyToClipboard'
        QtMocHelpers::MethodData<void(const QrCodeContent &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'copyImageToClipboard'
        QtMocHelpers::MethodData<void(const QImage &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Method 'hasApplication'
        QtMocHelpers::MethodData<bool(const QString &) const>(20, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'applicationIconName'
        QtMocHelpers::MethodData<QString(const QString &) const>(22, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'openInApplication'
        QtMocHelpers::MethodData<void(const QrCodeContent &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 21 },
        }}),
        // Method 'wifiName'
        QtMocHelpers::MethodData<QString(const QString &) const>(24, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'canConnectToWifi'
        QtMocHelpers::MethodData<bool() const>(26, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'connectToWifi'
        QtMocHelpers::MethodData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'resultContent'
        QtMocHelpers::MethodData<QrCodeContent(const Prison::ScanResult &)>(29, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Method 'scanImage'
        QtMocHelpers::MethodData<Prison::ScanResult(const QUrl &)>(32, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { 0x80000000 | 33, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'encodeText'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'wifiMode'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'connectingToWifi'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Qrca, qt_meta_tag_ZN4QrcaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Qrca::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4QrcaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4QrcaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4QrcaE_t>.metaTypes,
    nullptr
} };

void Qrca::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Qrca *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wifiModeChanged(); break;
        case 1: _t->connectingToWifiChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->passiveNotificationRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->encodeTextChanged(); break;
        case 4: _t->wifiConnected(); break;
        case 5: _t->wifiConnectionFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { QString _r = _t->newQrCodeSaveLocation();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->saveVCard((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: { QString _r = _t->getVCardName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->copyToClipboard((*reinterpret_cast<std::add_pointer_t<QrCodeContent>>(_a[1]))); break;
        case 10: _t->copyImageToClipboard((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 11: { bool _r = _t->hasApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->applicationIconName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->openInApplication((*reinterpret_cast<std::add_pointer_t<QrCodeContent>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: { QString _r = _t->wifiName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->canConnectToWifi();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->connectToWifi((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: { QrCodeContent _r = _t->resultContent((*reinterpret_cast<std::add_pointer_t<Prison::ScanResult>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QrCodeContent*>(_a[0]) = std::move(_r); }  break;
        case 18: { Prison::ScanResult _r = _t->scanImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Prison::ScanResult*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Qrca::*)()>(_a, &Qrca::wifiModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Qrca::*)(bool )>(_a, &Qrca::connectingToWifiChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Qrca::*)(QString )>(_a, &Qrca::passiveNotificationRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Qrca::*)()>(_a, &Qrca::encodeTextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Qrca::*)()>(_a, &Qrca::wifiConnected, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Qrca::*)(const QString & )>(_a, &Qrca::wifiConnectionFailed, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->encodeText(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->wifiMode(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->connectingToWifi(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEncodeText(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setWifiMode(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Qrca::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Qrca::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4QrcaE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Qrca::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Qrca::wifiModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Qrca::connectingToWifiChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Qrca::passiveNotificationRequested(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Qrca::encodeTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Qrca::wifiConnected()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Qrca::wifiConnectionFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
